/****************************************************************************
 * This is an example for the use of Audeme's MOVI(tm) Voice Control Shield *
 * ----> http://www.audeme.com/MOVI/                                        *
 * This code is inspired and maintained by Audeme but open to change        *
 * and organic development on GITHUB:                                       *
 * ----> https://github.com/audeme/MOVIArduinoAPI                           *
 * Written by Gerald Friedland for Audeme LLC.                              *
 * Contact: fractor@audeme.com                                              *
 * BSD license, all text above must be included in any redistribution.      *
 ****************************************************************************
 *
 * This basic example shows how to use MOVI(tm)'s API to train the call 
 * sign "Arduino" and two sentences. When the sentences are recognized
 * they switch on and off an LED on PIN D13. Many boards have a hardwired 
 * LED on board already connected to D13.
 *
 * Circuitry:
 * LED is pin D13 and GND
 * Arduino UNO R3, MEGA2560 R3, or Arduino Leonardo R3.
 * Connect speaker to MOVI.
 * IMPORTANT: Always use external power supply with MOVI. 
 * 
 * Other Arduino-compatible boards:  
 * Consult MOVI's User Manual before connecting MOVI.
 *
 * If you long-press the button on the MOVI (for a couple seconds), 
 * MOVI will revert back to the call sign and sentences trained here.
 */

#include "MOVIShield.h"     // Include MOVI library, needs to be *before* the next #include

#ifdef ARDUINO_ARCH_AVR 
#include <SoftwareSerial.h> // This is nice and flexible but only supported on AVR architecture, other boards need to use Serial1 
#endif
int val=0;//holding for read from camera
int val1=0;
int val2=0;
const int ball=4;
const int ball1=5;
const int frog=3;
const int led = 13;
 int number=1;//place to hold random number
const int turnaround=7;//turn around
MOVI recognizer(true);            // Get a MOVI object, true enables serial monitor interface, rx and tx can be passed as parameters for alternate communication pins on AVR architecture

void setup()  
{
  pinMode(led, OUTPUT);    // Make LED port writeable
  pinMode(turnaround,OUTPUT);
  pinMode(ball,INPUT);
  pinMode(ball1,INPUT);
  pinMode(frog,INPUT);
  digitalWrite(led, HIGH); // Blink LED.   
  delay(1);                   
  digitalWrite(led, LOW);  
  delay(1);
  randomSeed(analogRead(0));//set up random generator 

  recognizer.init();      // Initialize MOVI (waits for it to boot)

  //*
  // Note: training can only be performed in setup(). 
  // The training functions are "lazy" and only do something if there are changes. 
  // They can be commented out to save memory and startup time once training has been performed.
  recognizer.setVoiceGender(FEMALE_VOICE); 
  recognizer.callSign("Mato"); // Train callsign Arduino (may take 20 seconds)
  recognizer.addSentence("Ball!"); // Add sentence 1
  recognizer.addSentence("Froggy");            // Add sentence 2
  recognizer.addSentence("Move ahead quickly.");
  recognizer.train();                           // Train (may take 20seconds) 
  //*/

   recognizer.setThreshold(30);			// uncomment and set to a higher value (valid range 2-95) if you have a problems due to a noisy environment.
}

void loop() // run over and over
{
  signed int res=recognizer.poll(); // Get result from MOVI, 0 denotes nothing happened, negative values denote events (see docs)
  if (res==1) {                     // Sentence 1.
    digitalWrite(turnaround,LOW);
    digitalWrite(led, HIGH);        // Turn on LED
    recognizer.say("I see the pink ball. I am going to chase the pink ball.!"); // Speak a sentence
  } 
  if (res==2) {                    // Sentence 2
    digitalWrite(led,LOW); 
    digitalWrite(turnaround, HIGH);        // Turn on second LED
    recognizer.say("I love the little froggy. Please move out of the way, little froggy!");
  }
if (res==3) {
  digitalWrite(led,LOW);//turn off lights
  digitalWrite(turnaround,LOW);
  recognizer.say("Zoom. Zoom. Here I go!");
}
val=digitalRead(ball);
val1=digitalRead(ball1);
val2=digitalRead(frog);
if(val==HIGH or val1==HIGH) {

  number=random(1,6);//get random number
  switch(number) {
    
    case 1:  
  recognizer.say("I see the Pink ball. I will go to the pink ball. Pink ball, pink ball!");
  delay(15000);
  break;

   case 2:  
  recognizer.say("Look at the pink ball! Get the Pink Ball!");
  delay(15000);
  break;

   case 3:  
  recognizer.say("Happy! Happy! Pink ball ahead!");
  delay(15000);
  break;

   case 4:  
  recognizer.say("I am so lucky. Pink ball ahead, my pink ball.");
  delay(15000);
  break;

   case 5:  
  recognizer.say("There is nothing better than chasing a pink ball, my pink ball!");
  delay(15000);
  break;
  }
}
if(val2==HIGH) {

  recognizer.say("I love the little froggy. Please move out of the way, little froggy!");
  delay(8000);
  val2=digitalRead(frog);
  if(val2==LOW) {
    recognizer.say("Thank you for moving out of the way, little froggy!");
    
  }
  delay(7000);
  }
}




  
  // Do more ...

